# ListPolicyRulesResponse

The list of policies rules
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**policy_rules** | [**list[PolicyRule]**](PolicyRule.md) | List of policy rules | 
**limit** | **int** | Limit of policies in the response | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


